@@ -1,18 +1,18 @@
-function plot_identification(params,idemoments,idehess,idemodel, idelre, advanced, tittxt, name, IdentifDirectoryName,tit_TeX,name_tex)
+function plot_identification(params, idemoments, idehess, idemodel, idelre, advanced, tittxt, name, IdentifDirectoryName, tit_TeX, name_tex)
 % function plot_identification(params,idemoments,idehess,idemodel, idelre, advanced, tittxt, name, IdentifDirectoryName)
 %
 % INPUTS
-%    o params             [array] parameter values for identification checks
-%    o idemoments         [structure] identification results for the moments
-%    o idehess            [structure] identification results for the Hessian
-%    o idemodel           [structure] identification results for the reduced form solution
-%    o idelre             [structure] identification results for the LRE model
-%    o advanced           [integer] flag for advanced identification checks
-%    o tittxt             [char] name of the results to plot
-%    o name               [char] list of names
-%    o IdentifDirectoryName   [char] directory name
-%    o tittxt             [char] TeX-name of the results to plot
-%    o name_tex           [char] TeX-names of the parameters
+%    o params               [array] parameter values for identification checks
+%    o idemoments           [structure] identification results for the moments
+%    o idehess              [structure] identification results for the Hessian
+%    o idemodel             [structure] identification results for the reduced form solution
+%    o idelre               [structure] identification results for the LRE model
+%    o advanced             [integer] flag for advanced identification checks
+%    o tittxt               [char] name of the results to plot
+%    o name                 [char] list of names
+%    o IdentifDirectoryName [char] directory name
+%    o tittxt               [char] TeX-name of the results to plot
+%    o name_tex             [char] TeX-names of the parameters
 % OUTPUTS
 %    None
 %
@@ -47,39 +47,44 @@ if nargin <11
 end
 
 [SampleSize, nparam]=size(params);
-siJnorm = idemoments.siJnorm;
-siHnorm = idemodel.siHnorm;
-siLREnorm = idelre.siLREnorm;
+si_dMOMENTSnorm = idemoments.si_dMOMENTSnorm;
+si_dTAUnorm = idemodel.si_dREDUCEDFORMnorm;
+si_dLREnorm = idelre.si_dDYNAMICnorm;
 
-% if prior_exist,
-%     tittxt = 'Prior mean - ';
-% else
-%     tittxt = '';
-% end
 tittxt1=regexprep(tittxt, ' ', '_');
 tittxt1=strrep(tittxt1, '.', '');
 if SampleSize == 1
-    siJ = idemoments.siJ;
+    si_dMOMENTS = idemoments.si_dMOMENTS;
     hh = dyn_figure(options_.nodisplay,'Name',[tittxt, ' - Identification using info from observables']);
     subplot(211)
-    mmm = (idehess.ide_strength_J);
+    mmm = (idehess.ide_strength_dMOMENTS);
     [ss, is] = sort(mmm);
-    if ~all(isnan(idehess.ide_strength_J_prior))
-        bar(log([idehess.ide_strength_J(:,is)' idehess.ide_strength_J_prior(:,is)']))
+    if ~all(isnan(idehess.ide_strength_dMOMENTS_prior))
+        bar(1:nparam,log([idehess.ide_strength_dMOMENTS(:,is)' idehess.ide_strength_dMOMENTS_prior(:,is)']))
     else
-        bar(log([idehess.ide_strength_J(:,is)' ]))
+        bar(1:nparam,log([idehess.ide_strength_dMOMENTS(:,is)' ]))
     end
     hold on
-    plot((1:length(idehess.ide_strength_J(:,is)))-0.15,log([idehess.ide_strength_J(:,is)']),'o','MarkerSize',7,'MarkerFaceColor',[0 0 0],'MarkerEdgeColor','none')
-    plot((1:length(idehess.ide_strength_J_prior(:,is)))+0.15,log([idehess.ide_strength_J_prior(:,is)']),'o','MarkerSize',7,'MarkerFaceColor',[0 0 0],'MarkerEdgeColor','none')
-    if any(isinf(log(idehess.ide_strength_J(idehess.identified_parameter_indices))))
-        inf_indices=find(isinf(log(idehess.ide_strength_J(idehess.identified_parameter_indices))));
-        inf_pos=ismember(is,inf_indices);
+    plot((1:length(idehess.ide_strength_dMOMENTS(:,is)))-0.15,log([idehess.ide_strength_dMOMENTS(:,is)']),'o','MarkerSize',7,'MarkerFaceColor',[0 0 0],'MarkerEdgeColor','none')
+    plot((1:length(idehess.ide_strength_dMOMENTS_prior(:,is)))+0.15,log([idehess.ide_strength_dMOMENTS_prior(:,is)']),'o','MarkerSize',7,'MarkerFaceColor',[0 0 0],'MarkerEdgeColor','none')
+    if any(isinf(log(idehess.ide_strength_dMOMENTS(idehess.identified_parameter_indices))))
+        %-Inf, i.e. 0 strength
+        inf_indices=find(isinf(log(idehess.ide_strength_dMOMENTS(idehess.identified_parameter_indices))) & log(idehess.ide_strength_dMOMENTS(idehess.identified_parameter_indices))<0);
+        inf_pos=ismember(is,idehess.identified_parameter_indices(inf_indices));
+        plot(find(inf_pos)-0.15,zeros(sum(inf_pos),1),'o','MarkerSize',7,'MarkerFaceColor',[1 0 0],'MarkerEdgeColor',[0 0 0])
+        %+Inf, i.e. Inf strength
+        inf_indices=find(isinf(log(idehess.ide_strength_dMOMENTS(idehess.identified_parameter_indices))) & log(idehess.ide_strength_dMOMENTS(idehess.identified_parameter_indices))>0);
+        inf_pos=ismember(is,idehess.identified_parameter_indices(inf_indices));
         plot(find(inf_pos)-0.15,zeros(sum(inf_pos),1),'o','MarkerSize',7,'MarkerFaceColor',[1 1 1],'MarkerEdgeColor',[0 0 0])
     end
-    if any(isinf(log(idehess.ide_strength_J_prior(idehess.identified_parameter_indices))))
-        inf_indices=find(isinf(log(idehess.ide_strength_J_prior(idehess.identified_parameter_indices))));
-        inf_pos=ismember(is,inf_indices);
+    if any(isinf(log(idehess.ide_strength_dMOMENTS_prior(idehess.identified_parameter_indices))))
+        %-Inf, i.e. 0 strength
+        inf_indices=find(isinf(log(idehess.ide_strength_dMOMENTS_prior(idehess.identified_parameter_indices))) & log(idehess.ide_strength_dMOMENTS_prior(idehess.identified_parameter_indices))<0);
+        inf_pos=ismember(is,idehess.identified_parameter_indices(inf_indices));
+        plot(find(inf_pos)+0.15,zeros(sum(inf_pos),1),'o','MarkerSize',7,'MarkerFaceColor',[1 0 0],'MarkerEdgeColor',[0 0 0])
+        %+Inf, i.e. 0 strength
+        inf_indices=find(isinf(log(idehess.ide_strength_dMOMENTS_prior(idehess.identified_parameter_indices))) & log(idehess.ide_strength_dMOMENTS_prior(idehess.identified_parameter_indices))>0);
+        inf_pos=ismember(is,idehess.identified_parameter_indices(inf_indices));
         plot(find(inf_pos)+0.15,zeros(sum(inf_pos),1),'o','MarkerSize',7,'MarkerFaceColor',[1 1 1],'MarkerEdgeColor',[0 0 0])
     end
     set(gca,'xlim',[0 nparam+1])
@@ -88,7 +93,7 @@ if SampleSize == 1
     for ip=1:nparam
         text(ip,dy(1),name{is(ip)},'rotation',90,'HorizontalAlignment','right','interpreter','none')
     end
-    if ~all(isnan(idehess.ide_strength_J_prior))
+    if ~all(isnan(idehess.ide_strength_dMOMENTS_prior))
         legend('relative to param value','relative to prior std','Location','Best')
     else
         legend('relative to param value','Location','Best')
@@ -101,9 +106,9 @@ if SampleSize == 1
 
     subplot(212)
     if ~all(isnan(idehess.deltaM_prior))
-        bar(log([idehess.deltaM(is) idehess.deltaM_prior(is)]))
+        bar(1:nparam, log([idehess.deltaM(is) idehess.deltaM_prior(is)]))
     else
-        bar(log([idehess.deltaM(is)]))
+        bar(1:nparam, log([idehess.deltaM(is)]))
     end
     hold on
     plot((1:length(idehess.deltaM(is)))-0.15,log([idehess.deltaM(is)']),'o','MarkerSize',7,'MarkerFaceColor',[0 0 0],'MarkerEdgeColor','none')
@@ -154,18 +159,18 @@ if SampleSize == 1
     if advanced
         if ~options_.nodisplay
             skipline()
-            disp('Press ENTER to plot advanced diagnostics'), pause(5),
+            disp('Plotting advanced diagnostics')
         end
-        if all(isnan([siJnorm';siHnorm';siLREnorm']))
+        if all(isnan([si_dMOMENTSnorm';si_dTAUnorm';si_dLREnorm']))
             fprintf('\nIDENTIFICATION: Skipping sensitivity plot, because standard deviation of parameters is NaN, possibly due to the use of ML.\n')
         else
             hh = dyn_figure(options_.nodisplay,'Name',[tittxt, ' - Sensitivity plot']);
             subplot(211)
-            mmm = (siJnorm)'./max(siJnorm);
-            mmm1 = (siHnorm)'./max(siHnorm);
+            mmm = (si_dMOMENTSnorm)'./max(si_dMOMENTSnorm);
+            mmm1 = (si_dTAUnorm)'./max(si_dTAUnorm);
             mmm=[mmm mmm1];
-            mmm1 = (siLREnorm)'./max(siLREnorm);
-            offset=length(siHnorm)-length(siLREnorm);
+            mmm1 = (si_dLREnorm)'./max(si_dLREnorm);
+            offset=length(si_dTAUnorm)-length(si_dLREnorm);
             mmm1 = [NaN(offset,1); mmm1];
             mmm=[mmm mmm1];
 
@@ -194,7 +199,7 @@ if SampleSize == 1
             end
         end
         % identificaton patterns
-        for  j=1:size(idemoments.cosnJ,2)
+        for  j=1:size(idemoments.cosndMOMENTS,2)
             pax=NaN(nparam,nparam);
             %             fprintf('\n')
             %             disp(['Collinearity patterns with ', int2str(j) ,' parameter(s)'])
@@ -207,10 +212,10 @@ if SampleSize == 1
                         namx=[namx ' ' sprintf('%-15s','--')];
                     else
                         namx=[namx ' ' sprintf('%-15s',name{dumpindx})];
-                        pax(i,dumpindx)=idemoments.cosnJ(i,j);
+                        pax(i,dumpindx)=idemoments.cosndMOMENTS(i,j);
                     end
                 end
-                %                 fprintf('%-15s [%s] %10.3f\n',name{i},namx,idemoments.cosnJ(i,j))
+                %                 fprintf('%-15s [%s] %10.3f\n',name{i},namx,idemoments.cosndMOMENTS(i,j))
             end
             hh = dyn_figure(options_.nodisplay,'Name',[tittxt,' - Collinearity patterns with ', int2str(j) ,' parameter(s)']);
             imagesc(pax,[0 1]);
@@ -332,15 +337,15 @@ if SampleSize == 1
 else
     hh = dyn_figure(options_.nodisplay,'Name',['MC sensitivities']);
     subplot(211)
-    mmm = (idehess.ide_strength_J);
+    mmm = (idehess.ide_strength_dMOMENTS);
     [ss, is] = sort(mmm);
-    mmm = mean(siJnorm)';
+    mmm = mean(si_dMOMENTSnorm)';
     mmm = mmm./max(mmm);
     if advanced
-        mmm1 = mean(siHnorm)';
+        mmm1 = mean(si_dTAUnorm)';
         mmm=[mmm mmm1./max(mmm1)];
-        mmm1 = mean(siLREnorm)';
-        offset=size(siHnorm,2)-size(siLREnorm,2);
+        mmm1 = mean(si_dLREnorm)';
+        offset=size(si_dTAUnorm,2)-size(si_dLREnorm,2);
         mmm1 = [NaN(offset,1); mmm1./max(mmm1)];
         mmm=[mmm mmm1];
     end
@@ -374,7 +379,7 @@ else
     if advanced
         if ~options_.nodisplay,
             skipline()
-            disp('Press ENTER to display advanced diagnostics'), pause(5),
+            disp('Displaying advanced diagnostics')
         end
         %         options_.nograph=1;
         hh = dyn_figure(options_.nodisplay,'Name','MC Condition Number');
@@ -499,5 +504,3 @@ else
         end
     end
 end
-
-% disp_identification(params, idemodel, idemoments, name)
\ No newline at end of file
