@@ -30,7 +30,7 @@ function myoutput=prior_posterior_statistics_core(myinputs,fpar,B,whoiam, ThisMa
 % SPECIAL REQUIREMENTS.
 %   None.
 
-% Copyright (C) 2005-2017 Dynare Team
+% Copyright (C) 2005-2020 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -203,8 +203,8 @@ for b=fpar:B
     M_ = set_all_parameters(deep,estim_params_,M_);
 
     if run_smoother
-        [dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
-        [alphahat,etahat,epsilonhat,alphatilde,SteadyState,trend_coeff,aK,junk1,junk2,P,junk4,junk5,trend_addition,state_uncertainty,M_,oo_,options_,bayestopt_] = ...
+        [dr,info,M_,options_,oo_] =compute_decision_rules(M_,options_,oo_);
+        [alphahat,etahat,epsilonhat,alphatilde,SteadyState,trend_coeff,aK,~,~,P,~,~,trend_addition,state_uncertainty,M_,oo_,options_,bayestopt_] = ...
             DsgeSmoother(deep,gend,Y,data_index,missing_value,M_,oo_,options_,bayestopt_,estim_params_);
 
         stock_trend_coeff(options_.varobs_id,irun(9))=trend_coeff;
@@ -226,9 +226,9 @@ for b=fpar:B
         %% Compute constant for observables
         if options_.prefilter == 1 %as mean is taken after log transformation, no distinction is needed here
             constant_part=repmat(mean_varobs',1,gend);
-        elseif options_.prefilter == 0 && options_.loglinear == 1 %logged steady state must be used
+        elseif options_.prefilter == 0 && options_.loglinear %logged steady state must be used
             constant_part=repmat(log(SteadyState(IdObs)),1,gend);
-        elseif options_.prefilter == 0 && options_.loglinear == 0 %unlogged steady state must be used
+        elseif options_.prefilter == 0 && ~options_.loglinear %unlogged steady state must be used
             constant_part=repmat(SteadyState(IdObs),1,gend);
         end
         %add trend to observables
