@@ -1,4 +1,4 @@
-function [info, oo_, options_] = stoch_simul(M_, options_, oo_, var_list)
+function [info, oo_, options_, M_] = stoch_simul(M_, options_, oo_, var_list)
 
 % Copyright (C) 2001-2020 Dynare Team
 %
@@ -201,7 +201,7 @@ end
 
 if options_.irf
     var_listTeX = M_.endo_names_tex(i_var);
-    if ~options_.nograph
+    if ~options_.nograph || (TeX && any(strcmp('eps',cellstr(options_.graph_format))))
         if ~exist([M_.fname '/graphs'],'dir')
             mkdir(M_.fname,'graphs');
         end
@@ -393,3 +393,5 @@ end
 options_ = options_old;
 % temporary fix waiting for local options
 options_.partial_information = 0;
+
+oo_.gui.ran_stoch_simul = true;
